# CHANGELOG for pwlfit

## Introduction

This is the log of changes to the [pwlfit package](https://github.com/dkirkby/pwlfit).

All notable changes to this project will be documented in this file. The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2025-04-01

Initial migration from a jupyter notebook to a repo.
